Crate indexed_db_futures_macros_internal

Crate indexed_db_futures_macros_internal 

Internal macros for the indexed_db_futures crate. The API is to be considered unstable and subject to breaking changes at any time, although these will follow semver.

Attribute Macros

errdoc
Document the errors this fn returns
generate_with
Generate a with_ setter for a set_ setter
generic_bounds
Add consistent generic bounds across the crate. See options.

Derive Macros

BuildIntoFut
Derive an IntoFuture for variations of the type that implement BuildPrimitive.
FutureFromPollUnpinned
Derive a Future from a PollUnpinned.
StructName
Derive StructName
StructNameDebug
Delegate debug to inner type, wrap with type name.
dom_exception_err
Implement From<DomException>