Internal macros for the indexed_db_futures crate. The API is to be considered unstable and subject to breaking changes at any time, although these will follow semver.
Attribute Macros
- errdoc
- Document the errors this fn returns
- generate_
with - Generate a
with_setter for aset_setter - generic_
bounds - Add consistent generic bounds across the crate. See options.
Derive Macros
- Build
Into Fut - Derive an
IntoFuturefor variations of the type that implementBuildPrimitive. - Future
From Poll Unpinned - Derive a
Futurefrom aPollUnpinned. - Struct
Name - Derive
StructName - Struct
Name Debug - Delegate debug to inner type, wrap with type name.
- dom_
exception_ err - Implement
From<DomException>